@@ -6,15 +6,17 @@ use autodie;
 use App::RL -command;
 use App::RL::Common;
 
-use constant abstract => 'coverage statistics on chromosomes for runlists';
+sub abstract {
+    return 'coverage statistics on chromosomes for runlists';
+}
 
 sub opt_spec {
     return (
-        [ "outfile|o=s", "Output filename. [stdout] for screen." ],
+        [ "outfile|o=s", "output filename. [stdout] for screen" ],
         [ "size|s=s", "chr.sizes", { required => 1 } ],
-        [ "remove|r", "Remove 'chr0' from chromosome names." ],
-        [ "mk",       "YAML file contains multiple sets of runlists." ],
-        [ "all",      "Only write whole genome stats." ],
+        [ "remove|r", "remove 'chr0' from chromosome names" ],
+        [ "mk",       "YAML file contains multiple sets of runlists" ],
+        [ "all",      "only write whole genome stats" ],
         { show_defaults => 1, }
     );
 }
